====
nwe
====

O nwe é programa usado para gerar cards do `ANKI`_ e pdf, a partir do site `News Web Easy`_ , ele vai pegar as palavras e procurar o significado no `Jisho`_ e depois traduzir para português usando o `googletrans`_.

.. _ANKI: https://ankiweb.net/
.. _News Web Easy: https://www3.nhk.or.jp/news/easy/
.. _Jisho: https://jisho.org/
.. _googletrans: https://github.com/ssut/py-googletrans/

Instalação
----------

Para instalar, use o pip3 com o pacote "nwe".

.. code:: bash

    $ pip3 install nwe

Funcionamento
-------------

a partir do site `News Web Easy`_ , você pode ir nesse site e escolher um artigo, como esse do link de `exemplo`_ copia essa url e insere em **insira o link:**, ai clicar no botão **iniciar**, espera a **barra de progresso** completar, logo depois desse processo, você já pode gerar o Pdf e o card do anki. 

.. _News Web Easy: https://www3.nhk.or.jp/news/easy/
.. _exemplo: https://www3.nhk.or.jp/news/easy/k10012787711000/k10012787711000.html


Licença
-------

::
	MIT License

	Copyright (c) 2020 narutolavo

	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all
	copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
	SOFTWARE.


